@@ -349,6 +349,9 @@ fn main() {
     // C2Rust still generates old-style ASM -- workaround for https://github.com/immunant/c2rust/issues/306
     rustcode = rustcode.replace(" asm!(", " llvm_asm!(");
 
+    // Workaround for https://github.com/immunant/c2rust/issues/372
+    rustcode = rustcode.replace("::core::intrinsics::", "crate::intrinsics_replacements::");
+
     println!("cargo:rerun-if-env-changed=CARGO_FEATURE_KEEP_EXTERN_TYPES");
     if env::var("CARGO_FEATURE_KEEP_EXTERN_TYPES").is_err() {
         // There's only one `pub type` usually, and that breaks use on stable, and src/inline.rs has a
@@ -470,6 +473,12 @@ fn main() {
         "thread_getpid",
         "thread_get_unchecked",
         "ztimer_spin",
+        // because when defined through RIOT's af.h these are enums and thus unix_af_t prefixed.
+        "AF_UNSPEC",
+        "AF_UNIX",
+        "AF_PACKET",
+        "AF_INET",
+        "AF_INET6",
     ]
     .iter()
     .map(|name| name.to_string())
@@ -479,7 +488,9 @@ fn main() {
     }
     let toplevel_from_inline: Vec<String> = toplevel_from_inline
         .drain(..)
-        .filter(|s: &String| rustcode.contains(&format!(" {}(", s)))
+        .filter(|s: &String| {
+            rustcode.contains(&format!(" {}(", s)) || rustcode.contains(&format!(" {}: ", s))
+        })
         .collect();
     let toplevel_from_inline_filename = out_path.join("toplevel_from_inline.rs");
     std::fs::File::create(toplevel_from_inline_filename)
@@ -533,6 +544,7 @@ fn main() {
         ("ztimer_periodic_callback_t", "ztimer_periodic_callback_t"),
         // See https://github.com/RIOT-OS/RIOT/pull/17544, available TBD
         ("coap_build_pkt_t", "coap_build_pkt_t"),
+        ("gcoap_resource_t", "gcoap_resource_t"),
     ];
     for (needle, name) in markers {
         if bindgen_output.contains(needle) {
